==> open-next-cdk-0.0.6-sources.jar: io/dataspray/opennextcdk/NextjsLayer.java <==
package io.dataspray.opennextcdk;

/**
 * Lambda layer for Next.js. Contains Sharp 0.30.0.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-07-30T03:46:44.257Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.NextjsLayer")
public class NextjsLayer extends software.amazon.awscdk.services.lambda.LayerVersion {

    protected NextjsLayer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NextjsLayer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public NextjsLayer(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.dataspray.opennextcdk.NextjsLayerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link io.dataspray.opennextcdk.NextjsLayer}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.dataspray.opennextcdk.NextjsLayer> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.dataspray.opennextcdk.NextjsLayerProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.dataspray.opennextcdk.NextjsLayerProps.Builder();
        }

        /**
         * @returns a newly built instance of {@link io.dataspray.opennextcdk.NextjsLayer}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.dataspray.opennextcdk.NextjsLayer build() {
            return new io.dataspray.opennextcdk.NextjsLayer(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> open-next-cdk-0.0.9-sources.jar: io/dataspray/opennextcdk/NextjsLayer.java <==
package io.dataspray.opennextcdk;

/**
 * Lambda layer for Next.js. Contains Sharp 0.30.0.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.86.0 (build bc5c93a)", date = "2023-09-25T15:41:32.951Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.NextjsLayer")
public class NextjsLayer extends software.amazon.awscdk.services.lambda.LayerVersion {

    protected NextjsLayer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NextjsLayer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public NextjsLayer(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.dataspray.opennextcdk.NextjsLayerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link io.dataspray.opennextcdk.NextjsLayer}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.dataspray.opennextcdk.NextjsLayer> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.dataspray.opennextcdk.NextjsLayerProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.dataspray.opennextcdk.NextjsLayerProps.Builder();
        }

        /**
         * @return a newly built instance of {@link io.dataspray.opennextcdk.NextjsLayer}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.dataspray.opennextcdk.NextjsLayer build() {
            return new io.dataspray.opennextcdk.NextjsLayer(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
